@@ -107,11 +107,13 @@ def get_tianshou_envs(make_env, args):
         [lambda: make_env(mode='test', args=args) for _ in range(args.test_num)])
     return training_env, test_env, train_envs, train_envs2, test_envs
 
+
 def get_tianshou_logger(log_dir):
     from tianshou.utils import TensorboardLogger
     from torch.utils.tensorboard import SummaryWriter
     return TensorboardLogger(SummaryWriter(log_dir))
 
+
 def get_encoder_and_decoder(dim, hidden_dim, z_dim, hidden_sizes_for_enc=None):
     import numpy as np
     import torch
@@ -147,8 +149,7 @@ def get_encoder_and_decoder(dim, hidden_dim, z_dim, hidden_sizes_for_enc=None):
         if len(dim) == 1:
             dim = dim[0]
         if hidden_sizes_for_enc is None:
-            hidden_sizes_for_enc = [hidden_dim]*3
-
+            hidden_sizes_for_enc = [hidden_dim] * 3
 
         enc = MLP(input_dim=dim, output_dim=2 * z_dim, hidden_sizes=hidden_sizes_for_enc)
         dec = MLP(input_dim=z_dim, output_dim=dim, hidden_sizes=[hidden_dim])
@@ -158,4 +159,12 @@ def get_encoder_and_decoder(dim, hidden_dim, z_dim, hidden_sizes_for_enc=None):
 
 def load_pickle(path):
     import pickle
-    return pickle.load(open(path, 'rb'))
\ No newline at end of file
+    return pickle.load(open(path, 'rb'))
+
+
+def load_config(config_path, config_name):
+    import os
+    import yaml
+    with open(os.path.join(config_path, config_name)) as file:
+        config = yaml.safe_load(file)
+    return config
