@@ -160,18 +160,18 @@ def offpolicy_trainer(
             if t.n <= t.total:
                 t.update()
         # test
-        train_succ = test_fn(epoch, env_step)
-        if stop_fn(train_succ):
-            if save_fn:
-                save_fn(policy)
-            logger.save_data(
-                epoch, env_step, gradient_step, save_checkpoint_fn
-            )
-            t.set_postfix(**data)
-            return gather_info(
-                start_time, train_collector, test_collector,
-                test_result["rew"], test_result["rew_std"]
-            )
+        test_fn(epoch, env_step)
+        # if stop_fn(train_succ):
+        #     if save_fn:
+        #         save_fn(policy)
+        #     logger.save_data(
+        #         epoch, env_step, gradient_step, save_checkpoint_fn
+        #     )
+        #     t.set_postfix(**data)
+        #     return gather_info(
+        #         start_time, train_collector, test_collector,
+        #         test_result["rew"], test_result["rew_std"]
+        #     )
 
         logger.save_data(epoch, env_step, gradient_step, save_checkpoint_fn)
 
@@ -180,13 +180,13 @@ def offpolicy_trainer(
     )
 
 
-def run_offpolicy_trainer(trainer, tester, args):
+def run_offpolicy_trainer(trainer, tester, config):
     offpolicy_trainer(
-        tester.policy, tester.collector['train'], tester.collector['test'], args.epoch, args.step_per_epoch,
-        args.step_per_collect,
-        args.test_num, args.batch_size, update_per_step=1 / args.step_per_collect,
+        tester.policy, trainer.collector, tester.collector, config["epoch"], config["step_per_epoch"],
+        config["step_per_collect"],
+        config["test_num"], config["batch_size"], update_per_step=1 / config["step_per_collect"],
         train_fn=trainer.train_fn,
         test_fn=tester.test_fn,
-        stop_fn=lambda training_rew: training_rew > TRAIN_SUCCESS_RATE_THRESHOLD,
+        # stop_fn=lambda training_rew: training_rew > TRAIN_SUCCESS_RATE_THRESHOLD,
         logger=tester.logger
     )
